@@ -256,18 +256,18 @@ get_toplevel (void)
 }
 
 static char *
-get_sysconfdir (void)
+get_libdir (void)
 {
-  static char *sysconfdir = NULL;
+  static char *libdir = NULL;
 
-  if (sysconfdir == NULL)
-          sysconfdir = g_build_filename (get_toplevel (), "etc", NULL);
+  if (libdir == NULL)
+          libdir = g_build_filename (get_toplevel (), "lib", NULL);
 
-  return sysconfdir;
+  return libdir;
 }
 
-#undef GDK_PIXBUF_SYSCONFDIR
-#define GDK_PIXBUF_SYSCONFDIR get_sysconfdir()
+#undef GDK_PIXBUF_LIBDIR
+#define GDK_PIXBUF_LIBDIR get_libdir()
 
 static void
 correct_prefix (gchar **path)
@@ -2649,7 +2649,7 @@ _gdk_pixbuf_get_format (GdkPixbufModule *module)
  * Obtains the available information about the image formats supported
  * by GdkPixbuf.
  *
- * Returns: (transfer container): (element-type GdkPixbufFormat): A list of
+ * Returns: (transfer container) (element-type GdkPixbufFormat): A list of
  * #GdkPixbufFormat<!-- -->s describing the supported
  * image formats.  The list should be freed when it is no longer needed,
  * but the structures themselves are owned by #GdkPixbuf and should not be
@@ -2708,16 +2708,6 @@ gdk_pixbuf_format_free (GdkPixbufFormat *format)
                 g_slice_free (GdkPixbufFormat, format);
 }
 
-GType
-gdk_pixbuf_format_get_type (void)
-{
-        static volatile gsize format_id__volatile = 0;
-        if (g_once_init_enter (&format_id__volatile)) {
-                GType format_id =
-                        g_boxed_type_register_static (g_intern_static_string ("GdkPixbufFormat"),
-                                                      (GBoxedCopyFunc) gdk_pixbuf_format_copy,
-                                                      (GBoxedFreeFunc) gdk_pixbuf_format_free);
-                g_once_init_leave (&format_id__volatile, format_id);
-        }
-        return format_id__volatile;
-}
+G_DEFINE_BOXED_TYPE (GdkPixbufFormat, gdk_pixbuf_format,
+		     gdk_pixbuf_format_copy,
+		     gdk_pixbuf_format_free)
